# Postbox — done.md
> Audit-Log · Commit-Hash ist Pflicht

| #ID | Task | Agent | fb-data Commit-Hash | Datum |
|---|---|---|---|---|
| — | — | — | — | — |

<!-- Format:
| #T001 | Kurzbeschreibung | Claude Code | abc1234 | YYYY-MM-DD |
-->
